==> qcs-api-client-0.6.2.dev1074480209.tar.gz: qcs-api-client-0.6.2.dev1074480209/qcs_api_client/api/client_applications/get_client_application.py <==
from typing import Any, Dict

import httpx
from retrying import retry

from ...models.client_application import ClientApplication
from ...types import Response
from ...util.errors import QCSHTTPStatusError, raise_for_status
from ...util.retry import DEFAULT_RETRY_ARGUMENTS


def _get_kwargs(
    *,
    client_application_name: str,
) -> Dict[str, Any]:

    return {}


def _parse_response(*, response: httpx.Response) -> ClientApplication:
    raise_for_status(response)
    if response.status_code == 200:
        response_200 = ClientApplication.from_dict(response.json())

        return response_200
    else:
        raise QCSHTTPStatusError(
            f"Unexpected response: status code {response.status_code}", response=response, error=None
        )


def _build_response(*, response: httpx.Response) -> Response[ClientApplication]:
    """
    Construct the Response class from the raw ``httpx.Response``.
    """
    return Response.build_from_httpx_response(response=response, parse_function=_parse_response)


@retry(**DEFAULT_RETRY_ARGUMENTS)
def sync(
    *,
    client: httpx.Client,
    client_application_name: str,
) -> Response[ClientApplication]:
    url = "/v1/clientApplications/{clientApplicationName}".format(
        clientApplicationName=client_application_name,
    )

    kwargs = _get_kwargs(
        client_application_name=client_application_name,
    )
    response = client.request(
        "get",
        url,
        **kwargs,
    )
    return _build_response(response=response)


@retry(**DEFAULT_RETRY_ARGUMENTS)
def sync_from_dict(
    *,
    client: httpx.Client,
    client_application_name: str,
) -> Response[ClientApplication]:

    url = "/v1/clientApplications/{clientApplicationName}".format(
        clientApplicationName=client_application_name,
    )

    kwargs = _get_kwargs(
        client_application_name=client_application_name,
    )

    response = client.request(
        "get",
        url,
        **kwargs,
    )

    return _build_response(response=response)


@retry(**DEFAULT_RETRY_ARGUMENTS)
async def asyncio(
    *,
    client: httpx.AsyncClient,
    client_application_name: str,
) -> Response[ClientApplication]:
    url = "/v1/clientApplications/{clientApplicationName}".format(
        clientApplicationName=client_application_name,
    )

    kwargs = _get_kwargs(
        client_application_name=client_application_name,
    )

    response = await client.request("get", url, **kwargs)

    return _build_response(response=response)


@retry(**DEFAULT_RETRY_ARGUMENTS)
async def asyncio_from_dict(
    *,
    client: httpx.AsyncClient,
    client_application_name: str,
) -> Response[ClientApplication]:

    url = "/v1/clientApplications/{clientApplicationName}".format(
        clientApplicationName=client_application_name,
    )

    kwargs = _get_kwargs(
        client_application_name=client_application_name,
    )

    response = await client.request("get", url, **kwargs)

    return _build_response(response=response)

==> qcs-api-client-0.20.8.tar.gz: qcs-api-client-0.20.8/qcs_api_client/api/client_applications/get_client_application.py <==
from typing import Any, Dict

import httpx
from retrying import retry

from ...models.client_application import ClientApplication
from ...types import Response
from ...util.errors import QCSHTTPStatusError, raise_for_status
from ...util.retry import DEFAULT_RETRY_ARGUMENTS


def _get_kwargs(
    *,
    client_application_name: str,
) -> Dict[str, Any]:

    return {}


def _parse_response(*, response: httpx.Response) -> ClientApplication:
    raise_for_status(response)
    if response.status_code == 200:
        response_200 = ClientApplication.from_dict(response.json())

        return response_200
    else:
        raise QCSHTTPStatusError(
            f"Unexpected response: status code {response.status_code}", response=response, error=None
        )


def _build_response(*, response: httpx.Response) -> Response[ClientApplication]:
    """
    Construct the Response class from the raw ``httpx.Response``.
    """
    return Response.build_from_httpx_response(response=response, parse_function=_parse_response)


@retry(**DEFAULT_RETRY_ARGUMENTS)
def sync(
    *,
    client: httpx.Client,
    client_application_name: str,
    httpx_request_kwargs: Dict[str, Any] = {},
) -> Response[ClientApplication]:
    url = "/v1/clientApplications/{clientApplicationName}".format(
        clientApplicationName=client_application_name,
    )

    kwargs = _get_kwargs(
        client_application_name=client_application_name,
    )
    kwargs.update(httpx_request_kwargs)
    response = client.request(
        "get",
        url,
        **kwargs,
    )
    return _build_response(response=response)


@retry(**DEFAULT_RETRY_ARGUMENTS)
def sync_from_dict(
    *,
    client: httpx.Client,
    client_application_name: str,
    httpx_request_kwargs: Dict[str, Any] = {},
) -> Response[ClientApplication]:

    url = "/v1/clientApplications/{clientApplicationName}".format(
        clientApplicationName=client_application_name,
    )

    kwargs = _get_kwargs(
        client_application_name=client_application_name,
    )
    kwargs.update(httpx_request_kwargs)
    response = client.request(
        "get",
        url,
        **kwargs,
    )
    return _build_response(response=response)


@retry(**DEFAULT_RETRY_ARGUMENTS)
async def asyncio(
    *,
    client: httpx.AsyncClient,
    client_application_name: str,
    httpx_request_kwargs: Dict[str, Any] = {},
) -> Response[ClientApplication]:
    url = "/v1/clientApplications/{clientApplicationName}".format(
        clientApplicationName=client_application_name,
    )

    kwargs = _get_kwargs(
        client_application_name=client_application_name,
    )
    kwargs.update(httpx_request_kwargs)
    response = await client.request(
        "get",
        url,
        **kwargs,
    )
    return _build_response(response=response)


@retry(**DEFAULT_RETRY_ARGUMENTS)
async def asyncio_from_dict(
    *,
    client: httpx.AsyncClient,
    client_application_name: str,
    httpx_request_kwargs: Dict[str, Any] = {},
) -> Response[ClientApplication]:

    url = "/v1/clientApplications/{clientApplicationName}".format(
        clientApplicationName=client_application_name,
    )

    kwargs = _get_kwargs(
        client_application_name=client_application_name,
    )
    kwargs.update(httpx_request_kwargs)
    response = await client.request(
        "get",
        url,
        **kwargs,
    )
    return _build_response(response=response)
